/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2015 Camil Staps <info@camilstaps.nl>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.camilstaps.die;

/**
 * A player rolling a die
 * @author Camil Staps, s4498062
 */
public class Player implements Runnable {
    private final Die die;
    private final String name;
    private final int numberOfThrows;
    private int pipss[];
    
    /**
     * The player will perform a number of rolls of a die
     * @param name the name of the player
     * @param die the die to use
     * @param numberOfThrows the number of rolls
     */
    public Player(String name, Die die, int numberOfThrows) {
        this.die = die;
        this.name = name;
        this.numberOfThrows = numberOfThrows;
    }
    
    @Override
    public void run() {
        pipss = new int[numberOfThrows];
        for (int i = 0; i < numberOfThrows; i++) {
            int pips = die.roll();
            pipss[i] = pips;
            System.err.println(name + " throws " + pips + " in turn " + i); // Only debugging output; so stderr
        }
    }
    
    /**
     * The results we've found
     * @return the results of the die rolls
     */
    public int[] getPipss() {
        return pipss;
    }
}
